==> rtp-1.2.0.tar.gz: rtp_1_2_0/util/test/UdpStackVerify.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

#include "UdpStack.hxx"
#include "Verify.hxx"
#include "VThread.h"
#include "Fifo.h"
#include <stdio.h>

Fifo<int> recv2send;

void* sendThread(void*)
{
    UdpStack send;

    for(int i = 0; i < 1; i++)
    {
	NetworkAddress dest("127.0.0.1", 2048);
	char buf[1024];
	int len;

	sprintf(buf, "%d", i);

	int retCode;
	retCode = send.transmitTo(buf, strlen(buf) + 1, &dest);
	test_verify(retCode == 0);
    }
    return 0;
}


void* recvThread(void*)
{
    UdpStack receive(0, 2048, 2048);
    for(int i = 0; i < 1; i++)
    {
	NetworkAddress sender;
	char buf[1024];
	int len;

	len = receive.receiveFrom( buf , 1024 , &sender );
	test_verify(atoi(buf) == i);
    }
    recv2send.add(0);
    return 0;
}



int main()
{
    VThread send;
    VThread receive;

    recv2send.addDelayMs(-1, 5000);

    receive.spawn(recvThread, 0);
    usleep(1000);
    send.spawn(sendThread, 0);

    test_verify(recv2send.getNext() == 0);

    receive.join();
    send.join();

    return test_return_code();
}

==> rtp-1.4.0.tar.gz: rtp-1.4.0/util/test/UdpStackVerify.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

#include "UdpStack.hxx"
#include "Verify.hxx"
#include "VThread.hxx"
#include "Fifo.h"
#include <stdio.h>

using namespace Vocal;

Fifo<int> recv2send;

void* sendThread(void*)
{
    UdpStack send;

    for(int i = 0; i < 1; i++)
    {
	NetworkAddress dest("127.0.0.1", 2048);
	char buf[1024];
	int len;

	sprintf(buf, "%d", i);

	int retCode;
	retCode = send.transmitTo(buf, strlen(buf) + 1, &dest);
	test_verify(retCode == 0);
    }
    return 0;
}


void* recvThread(void*)
{
    UdpStack receive(0, 2048, 2048);
    for(int i = 0; i < 1; i++)
    {
	NetworkAddress sender;
	char buf[1024];
	int len;

	len = receive.receiveFrom( buf , 1024 , &sender );
	test_verify(atoi(buf) == i);
    }
    recv2send.add(0);
    return 0;
}



int main()
{
    VThread send;
    VThread receive;

    recv2send.addDelayMs(-1, 5000);

    receive.spawn(recvThread, 0);
    usleep(1000);
    send.spawn(sendThread, 0);

    test_verify(recv2send.getNext() == 0);

    receive.join();
    send.join();

    return test_return_code(0);
}
